+++
title = "Towards Manufacturing Logic Devices at Home"
description = ""
+++

open source rules the software ecosystem. we have Linux, GNU, and all the applications on top.
your device is near-infinitely hackable... at the software layer.

with Risc-V, Framework, and earlier projects like Novena, we're beginning to achieve
some of this same hackability at the hardware layer.

but the base layer -- the actual manufacturing of integrated circuits -- remains this
impenetrable wall. players like Sam Zeloof do some (small-scale, proof-of-concept)
IC manufacturing at home. and there's some defunct projects like HomeCMOS. but otherwise,
the space is close to a vacuum. how do we make inroads?

## We Don't Need Perfection

we don't need 5 GHz clock speeds and mobile-level power-consumption out of the gate.
even a 10 kHz, 1000 logic-element device has *some* value (say, as a keyboard driver).
once we have a foot in the door, incremental improvements can make the technology more
widely applicable. our problem of open-source computation is one of bootstrapping.

Silicon devices aren't friendly to manufacture. the equipment is expensive, the
chemicals are dangerous, the tolerances are small, and the physics/chemistry is
college-level to Phd-level.

when i was in middle school, i learned about electromagnets.
my dad took me to the hardware store and we bought several iron bolts,
annealed copper wire, paperclips, thumbtacks, and a lantern battery.
within a day, i had a two-bit electro-mechanical adder.
each bit was represented by three tacks and a paperclip. the paperclip was fixed to one
tack (A) and freely rotatable such that at one rotation it would bridge an electrical
connection to tack B and at a different rotation it would instead bridge a connection
to tack C (logic '0' and logic '1', respectively). by introducing an electromagnet,
i could conditionally pull the paperclip to one orientation or another.
it was in effect a relay, and since the tacks and paperclips could conduct electricity,
the relays could feed into each other.

relay computers were a thing. and they're simple enough that a motivated 12-year-old
can build one. they have a few notable downsides, but the largest for us in this
context is that they're very labor intensive to manufacture/assemble.

## Non-Silicon Forms of Computation

Wikipedia has an entire page on [Unconventional Computing](https://en.wikipedia.org/wiki/Unconventional_computing),
and it's not even complete. there's also
[Fluidics](https://en.wikipedia.org/wiki/Fluidics),
[Optical Computing](https://en.wikipedia.org/wiki/Optical_computing),
[Chemical Computing](https://en.wikipedia.org/wiki/Chemical_computer)
[Electrochemical Transistors](https://en.wikipedia.org/wiki/Organic_electrochemical_transistor),
and of course, vacuum tubes!

these things aren't just the realm of theory. they all had use before the reign of the transistor:
- vacuum tubes were the go-to before transistors. TODO: link.
- the [MONIAC](https://en.wikipedia.org/wiki/MONIAC) used fluids to model economic activity.
- OECTs are used in bio-sensing applications because they're safer than silicon in such settings. TODO: link

the point of listing these is break the misconception that computation _must_ take place on silicon,
or even semiconductors in general. the most alluring technology for my purpose looks to be _ferromagnetics_.

magnetic core memory was widespread before we had integrated circuits. the [Apollo Guidance Computer](TODO) used core memory for its program data.
lesser known, the [Elliott 803](https://en.wikipedia.org/wiki/Elliott_803#Hardware_description) repurposed core memory _into logic gates_.

magnetic cores are _really simple_: you have some ferromagnetic material which has some interesting, often _nonlinear_
relationship between its electric and magnetic field, and you have some conductor (copper) to carry these fields from
one place to another. that's two, easily procurable materials, plus an insulator (air). and it's all solid state
and (at a high level) operates on classical mechanics -- making it _scale independent_: a 1cm
core behaves roughly the same as a 100um core, only with power scaled accordingly. you don't _need_ precise fabrication, so
with some effort it should be possible to manufacture an integrated circuit out of these materials using something
like selective laser sintering (which could pair nicely with non-electronic home-manufacturing).

## Ferromagnetic Computing

it's widely known that _any_ combinatorial circuit can be reduced to a representation which uses _only_ NAND gates
(this includes flipflops, allowing not just combinatorial logic but also volatile storage, and hence general-purpose computation).
one could alternatively use NOR gates, XOR gates, or inhibit gates (`Y = A and not B`).

the Elliott 803 demonstrates a sort of inhibit gate, at an analog level: `Y = A - B` (based on the gate wiring, it could perform `Y = +/-A +/- B +/- C` with the sign configurable).
the reason it required transistors is because these analog operations were _lossy_, and needed amplification to achieve the desired digital operation.
that is, the "inhibit gate" might actually look something like `Y = 0.5*A - 0.5*B` and in order to feed this into the next gate you would need to amplify `Y` by 2,
which a transistor does nicely.

but that's not to say one _couldn't_ perform this amplification using ferromagnetics. in fact, magnetic amplifiers are all around us: _transformers_.

can we assemble these components into one of the primitive digital logic gates?

## TODO: review magnetic core theory


NOTES:
  Pneumatic Logic: https://www.instructables.com/Pneumatic-Logic-Gates-Made-With-Simple-Tools/
  # TODO: read 2020-09-25-technology.txt
  TODO: read http://www.hpfriedrichs.com/radioroom/cu-diode/rr-cu-diode.htm
  # TODO: read 2020-10-04-other-magnetic-logic.txt
  TODO: magnetic amplifiers https://en.wikipedia.org/wiki/Elliott_803#Hardware_description  (it uses cores for computation, and transistors to amplify the output)
  # TODO: read 2019-08-18-resources.txt
  TODO: 2020-04-05-unconventional-computing.txt
  Material Matters Basics Vol. 8: covers PDOT/PSS; conductive polymers
  TODO: Acquire: Material Matters Basics Vol. 6: The Fundamentals of Organic Transistors

  ion-beam lithography
